@@ -8,8 +8,9 @@ import sys
 import warnings
 
 from splinter.browser import Browser
-from jasmine_extractor import Extractor
-from report import print_result
+from extractors.jasmine import Extractor as JExtractor
+from extractors.qunit import Extractor as QExtractor
+from reporters.stdout import print_result
 
 
 def run_specs(path, browser_driver='webdriver.firefox'):
@@ -19,11 +20,10 @@ def run_specs(path, browser_driver='webdriver.firefox'):
     browser = Browser(browser_driver)
     browser.visit(path)
 
-    while browser.is_text_present("Running..."):
-        pass
+    Extractor = filter(lambda e: e.is_it_me(browser), [JExtractor, QExtractor])[0]
 
     extractor = Extractor(browser)
-    print_result(extractor)
+    extractor.wait_till_finished_and_then(print_result)
 
     browser.quit()
 
@@ -75,3 +75,4 @@ def main(args=sys.argv):
         runner_path = default_runner_path
 
     sys.exit(run_specs(runner_path, args.browser_driver))
+
